#include "childdlg.h"

/*
 *  Constructs a ChildDlg as a child of 'parent', with the 
 *  name 'name' and widget flags set to 'f'.
 *
 *  The dialog will by default be modeless, unless you set 'modal' to
 *  TRUE to construct a modal dialog.
 */
ChildDlg::ChildDlg( QWidget* parent, const char* name, bool modal, WFlags fl )
    : QDialog( parent, name, modal, fl )

{
    if ( !name )
	setName( "ChildDlg" );
    setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, 0, 0, sizePolicy().hasHeightForWidth() ) );
    setMinimumSize( QSize( 600, 480 ) );
    setMaximumSize( QSize( 600, 480 ) );

    // Sensor Group
    SensorBox = new QGroupBox( this, "SensorBox" );
    SensorBox->setGeometry( QRect( 20, 260, 561, 150 ) );

    useSens = new QCheckBox( SensorBox, "useSens" );
    useSens->setGeometry( QRect( 20, 20, 160, 21 ) );

    SensorCombo = new QComboBox( false, SensorBox, "SensorCombo" );
    SensorCombo->setEnabled( false );
    SensorCombo->setGeometry( QRect( 290, 20, 171, 21 ) );

    Format = new QLineEdit( SensorBox, "Format" );
    Format->setEnabled( false );
    Format->setGeometry( QRect( 102, 50, 150, 21 ) );

    Codec = new QLineEdit( SensorBox, "Codec" );
    Codec->setEnabled( false );
    Codec->setGeometry( QRect( 102, 90, 150, 21 ) );

    Line = new QLineEdit( SensorBox, "Line" );
    Line->setEnabled( false );
    Line->setGeometry( QRect( 400, 90, 150, 21 ) );

    Program = new QLineEdit( SensorBox, "Program" );
    Program->setEnabled( false );
    Program->setGeometry( QRect( 400, 50, 150, 21 ) );
    Program->setReadOnly( false );

    RDF = new QCheckBox( SensorBox, "RDF" );
    RDF->setGeometry( QRect( 20, 120, 160, 21 ) );
    RDF->setEnabled( false );

    LineLabel = new QLabel( SensorBox, "LineLabel" );
    LineLabel->setEnabled( false );
    LineLabel->setGeometry( QRect( 300, 90, 90, 21 ) );
    LineLabel->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignRight ) );

    ProgramLabel = new QLabel( SensorBox, "ProgramLabel" );
    ProgramLabel->setEnabled( false );
    ProgramLabel->setGeometry( QRect( 265, 50, 125, 21 ) );
    ProgramLabel->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignRight ) );

    FormatLabel = new QLabel( SensorBox, "FormatLabel" );
    FormatLabel->setEnabled( false );
    FormatLabel->setGeometry( QRect( 2, 50, 90, 21 ) );
    FormatLabel->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignRight ) );

    CodecLabel = new QLabel( SensorBox, "CodecLabel" );
    CodecLabel->setEnabled( false );
    CodecLabel->setGeometry( QRect( 2, 90, 90, 21 ) );
    CodecLabel->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignRight ) );

    SensorLabel = new QLabel( SensorBox, "SensorLabel" );
    SensorLabel->setEnabled( false );
    SensorLabel->setGeometry( QRect( 190, 20, 80, 21 ) );
    SensorLabel->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignRight ) );

    // Child Group
    groupBox1 = new QGroupBox( this, "groupBox1" );
    groupBox1->setGeometry( QRect( 20, 0, 561, 240 ) );
    groupBox1->setFrameShape( QGroupBox::GroupBoxPanel );
    groupBox1->setFrameShadow( QGroupBox::Sunken );

    Theme = new QLineEdit( groupBox1, "Theme" );
    Theme->setGeometry( QRect( 20, 50, 243, 21 ) );

    ThemeLabel = new QLabel( groupBox1, "ThemeLabel" );
    ThemeLabel->setGeometry( QRect( 20, 28, 221, 21 ) );

    pushButton3 = new QPushButton( groupBox1, "pushButton3" );
    pushButton3->setGeometry( QRect( 263, 45, 100, 31 ) );
    pushButton3->setIconSet( SmallIconSet( "fileopen" ));

    shEvents = new QComboBox( false, groupBox1, "shEvents" );
    shEvents->setGeometry( QRect( 20, 110, 220, 21 ) );

    shEventsLabel = new QLabel( groupBox1, "shEventsLabel" );
    shEventsLabel->setGeometry( QRect( 20, 88, 221, 21 ) );

    embed = new QCheckBox( groupBox1, "embed" );
    embed->setGeometry( QRect( 20, 150, 160, 21 ) );

    W = new QSpinBox( groupBox1, "W" );
    W->setGeometry( QRect( 450, 130, 70, 21 ) );
    W->setMaxValue( 2048 );

    WidthLabel = new QLabel( groupBox1, "WidthLabel" );
    WidthLabel->setGeometry( QRect( 380, 130, 60, 21 ) );
    WidthLabel->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignRight ) );

    H = new QSpinBox( groupBox1, "H" );
    H->setGeometry( QRect( 450, 170, 70, 21 ) );
    H->setMaxValue( 2048 );

    HeightLabel = new QLabel( groupBox1, "HeightLabel" );
    HeightLabel->setGeometry( QRect( 380, 170, 60, 21 ) );
    HeightLabel->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignRight ) );

    X = new QSpinBox( groupBox1, "X" );
    X->setGeometry( QRect( 450, 50, 70, 21 ) );
    X->setMaxValue( 2048 );

    XLabel = new QLabel( groupBox1, "XLabel" );
    XLabel->setGeometry( QRect( 380, 50, 60, 21 ) );
    XLabel->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignRight ) );

    Y = new QSpinBox( groupBox1, "Y" );
    Y->setGeometry( QRect( 450, 90, 70, 21 ) );
    Y->setMaxValue( 1200 );

    YLabel = new QLabel( groupBox1, "YLabel" );
    YLabel->setGeometry( QRect( 380, 90, 60, 21 ) );
    YLabel->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignRight ) );

    Tooltip = new QLineEdit( groupBox1, "Tooltip" );
    Tooltip->setGeometry( QRect( 20, 200, 343, 21 ) );

    TipLabel = new QLabel( groupBox1, "TipLabel" );
    TipLabel->setGeometry( QRect( 20, 180, 108, 20 ) );
    TipLabel->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignLeft ) );

    // Global
    insCur = new QCheckBox( this, "insCur" );
    insCur->setGeometry( QRect( 20, 415, 300, 20 ) );

    pushButton1 = new QPushButton( this, "pushButton1" );
    pushButton1->setGeometry( QRect( 190, 440, 81, 31 ) );
    pushButton1->setIconSet( SmallIconSet( "ok" ));
    pushButton1->setDefault( TRUE );

    pushButton2 = new QPushButton( this, "pushButton2" );
    pushButton2->setGeometry( QRect( 340, 440, 81, 31 ) );
    pushButton2->setIconSet( SmallIconSet( "cancel" ));

    languageChange();
    resize( QSize(600, 480).expandedTo(minimumSizeHint()) );

    // signals and slots connections
    connect( pushButton1, SIGNAL( clicked() ), this, SLOT( accept() ) );
    connect( pushButton2, SIGNAL( clicked() ), this, SLOT( close() ) );
    connect( pushButton3, SIGNAL( clicked() ), this, SLOT( selTheme() ) );
    connect( SensorCombo, SIGNAL( activated(const QString&) ), this, SLOT( ChooseProgram() ) );
    connect( useSens, SIGNAL( toggled(bool) ), this, SLOT( UseSensor(bool) ) );
}

/*
 *  Destroys the object and frees any allocated resources
 */
ChildDlg::~ChildDlg()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void ChildDlg::languageChange()
{
    // Global
    setCaption( tr2i18n( "Add Child Meter" ) );
    pushButton1->setText( tr2i18n( "Ok" ) );
    pushButton2->setText( tr2i18n( "Cancel" ) );
    insCur->setText( tr2i18n( "Insert at cursor position" ) );
    // Sensor Group
    SensorBox->setTitle( tr2i18n( "Sensor" ) );
    useSens->setText( tr2i18n( "Use sensor" ) );
    SensorCombo->clear();
    SensorCombo->insertItem( tr2i18n( "CPU" ) );
    SensorCombo->insertItem( tr2i18n( "Memory" ) );
    SensorCombo->insertItem( tr2i18n( "Disk" ) );
    SensorCombo->insertItem( tr2i18n( "Network" ) );
    SensorCombo->insertItem( tr2i18n( "Time" ) );
    SensorCombo->insertItem( tr2i18n( "Uptime" ) );
    SensorCombo->insertItem( tr2i18n( "Sensor" ) );
    SensorCombo->insertItem( tr2i18n( "Textfile" ) );
    SensorCombo->insertItem( tr2i18n( "Noatun" ) );
    SensorCombo->insertItem( tr2i18n( "XMMS" ) );
    SensorCombo->insertItem( tr2i18n( "Program" ) );
    Format->setText( tr2i18n( "%v" ) );
    ProgramLabel->setText( tr2i18n( "Program:" ) );
    FormatLabel->setText( tr2i18n( "Format:" ) );
    SensorLabel->setText( tr2i18n( "Sensor:" ) );
    LineLabel->setText( tr2i18n( "Line:" ) );
    RDF->setText( tr2i18n( "RDF file" ) );
    CodecLabel->setText( tr2i18n( "Encoding:" ) );
    // Child Group
    groupBox1->setTitle( tr2i18n( "Child Parameters" ) );
    ThemeLabel->setText( tr2i18n( "Theme:" ) );
    pushButton3->setText( tr2i18n( "Browse" ) );
    WidthLabel->setText( tr2i18n( "Width:" ) );
    X->setSuffix( tr2i18n( "px" ) );
    HeightLabel->setText( tr2i18n( "Height:" ) );
    H->setSuffix( tr2i18n( "px" ) );
    W->setSuffix( tr2i18n( "px" ) );
    XLabel->setText( tr2i18n( "X axis:" ) );
    Y->setSuffix( tr2i18n( "px" ) );
    YLabel->setText( tr2i18n( "Y axis:" ) );
    shEventsLabel->setText( tr2i18n( "Show / Hide Events:" ) );
    shEvents->clear();
    shEvents->insertItem( tr2i18n( "Mouse On / Out" ) );
    shEvents->insertItem( tr2i18n( "Mouse Click" ) );
    shEvents->insertItem( tr2i18n( "Mouse On / Loose Focus" ) );
    shEvents->insertItem( tr2i18n( "Mouse Click / Loose Focus" ) );
    shEvents->adjustSize();
    embed->setText( tr2i18n( "Embed in parent theme." ) );
    embed->adjustSize();
    TipLabel->setText( tr2i18n( "Tooltip:" ) );
    TipLabel->adjustSize();
}

void ChildDlg::UseSensor( bool v ){
  SensorLabel->setEnabled(v);
  SensorCombo->setEnabled(v);
  Format->setEnabled(v);
  FormatLabel->setEnabled(v);
  LineLabel->setEnabled(v);
  Line->setEnabled(v);
  ProgramLabel->setEnabled(v);
  Program->setEnabled(v);
  CodecLabel->setEnabled(v);
  Codec->setEnabled(v);
  RDF->setEnabled(v);
  Theme->setEnabled(!v);
  ThemeLabel->setEnabled(!v);
  pushButton3->setEnabled(!v);
  if(v){
    ChooseProgram();
  }
}

void ChildDlg::ChooseProgram(){
  if(SensorCombo->currentItem() == 0){
    ProgramLabel->setEnabled(false);
    Program->setEnabled(false);
    CodecLabel->setEnabled(false);
    Codec->setEnabled(false);
    FormatLabel->setEnabled(true);
    Format->setEnabled(true);
    Format->setText("%load");
    QToolTip::add( Format, tr2i18n( "%user<br>%system<br>%nice<br>%idle<br>%load (=%v)" ) );
    LineLabel->setEnabled(true);
    LineLabel->setText( tr2i18n( "CPU:" ) );
    Line->setEnabled(true);
    Line->setText("all");
    RDF->setEnabled(false);
  }
  else if(SensorCombo->currentItem() == 1){
    ProgramLabel->setEnabled(false);
    Program->setEnabled(false);
    CodecLabel->setEnabled(false);
    Codec->setEnabled(false);
    FormatLabel->setEnabled(true);
    Format->setEnabled(true);
    Format->setText("%fm");
    QToolTip::add( Format, tr2i18n( "%fm<br>%fmb<br>%um<br>%umb<br>%tm<br>%fs<br>%us<br>%ts" ) );
    LineLabel->setEnabled(false);
    Line->setEnabled(false);
    RDF->setEnabled(false);
  }
  else if(SensorCombo->currentItem() == 2){
    ProgramLabel->setEnabled(true);
    ProgramLabel->setText( tr2i18n( "MountPoint:" ) );
    Program->setEnabled(true);
    Program->setText("/");
    CodecLabel->setEnabled(false);
    Codec->setEnabled(false);
    FormatLabel->setEnabled(true);
    Format->setEnabled(true);
    Format->setText("%f");
    QToolTip::add( Format, tr2i18n( "%f<br>%fp<br>%u<br>%up<br>%t" ) );
    LineLabel->setEnabled(false);
    Line->setEnabled(false);
    RDF->setEnabled(false);
  }
  else if(SensorCombo->currentItem() == 3){
    ProgramLabel->setEnabled(true);
    ProgramLabel->setText( tr2i18n( "Device:" ) );
    Program->setEnabled(true);
    Program->setText("eth0");
    CodecLabel->setEnabled(false);
    Codec->setEnabled(false);
    FormatLabel->setEnabled(true);
    Format->setEnabled(true);
    Format->setText("%in");
    QToolTip::add( Format, tr2i18n( "%in<br>%out" ) );
    LineLabel->setEnabled(true);
    LineLabel->setText( tr2i18n( "Decimals:" ) );
    Line->setEnabled(true);
    Line->setText("0");
    RDF->setEnabled(false);
  }
  else if(SensorCombo->currentItem() == 4){
    ProgramLabel->setEnabled(false);
    Program->setEnabled(false);
    CodecLabel->setEnabled(false);
    Codec->setEnabled(false);
    FormatLabel->setEnabled(true);
    Format->setEnabled(true);
    Format->setText("dd.MM.yyyy");
    QToolTip::add( Format, tr2i18n( "d<br>dd<br>ddd<br>dddd<br>M<br>MM<br>MMM<br>MMMM<br>YY<br>YYYY<br>h<br>hh<br>m<br>mm<br>s<br>ss<br>z<br>zzz<br>AP<br>ap" ) );
    LineLabel->setEnabled(false);
    Line->setEnabled(false);
    RDF->setEnabled(false);
  }
  else if(SensorCombo->currentItem() == 5){
    ProgramLabel->setEnabled(false);
    Program->setEnabled(false);
    CodecLabel->setEnabled(false);
    Codec->setEnabled(false);
    FormatLabel->setEnabled(true);
    Format->setEnabled(true);
    Format->setText("%dd %h:%M");
    QToolTip::add( Format, tr2i18n( "%d<br>%h<br>%m<br>%s<br>%H<br>%M<br>%S" ) );
    LineLabel->setEnabled(false);
    Line->setEnabled(false);
    RDF->setEnabled(false);
  }
  else if(SensorCombo->currentItem() == 6){
    ProgramLabel->setEnabled(true);
    ProgramLabel->setText( tr2i18n( "Type:" ) );
    Program->setEnabled(true);
    Program->setText("temp2");
    CodecLabel->setEnabled(false);
    Codec->setEnabled(false);
    FormatLabel->setEnabled(true);
    Format->setEnabled(true);
    Format->setText("%v");
    QToolTip::add( Format, tr2i18n( "%v" ) );
    LineLabel->setEnabled(false);
    Line->setEnabled(false);
    RDF->setEnabled(false);
  }
  else if(SensorCombo->currentItem() == 7){
    ProgramLabel->setEnabled(true);
    ProgramLabel->setText( tr2i18n( "Path:" ) );
    Program->setEnabled(true);
    Program->setText("");
    CodecLabel->setEnabled(true);
    Codec->setEnabled(true);
    Codec->setText((QTextCodec::codecForLocale())->name());
    FormatLabel->setEnabled(true);
    Format->setEnabled(true);
    Format->setText("%v");
    QToolTip::add( Format, tr2i18n( "%v" ) );
    LineLabel->setEnabled(true);
    LineLabel->setText( tr2i18n( "Line:" ) );
    Line->setEnabled(true);
    Line->setText("");
    RDF->setEnabled(true);
  }
  else if(SensorCombo->currentItem() == 8){
    ProgramLabel->setEnabled(false);
    Program->setEnabled(false);
    CodecLabel->setEnabled(false);
    Codec->setEnabled(false);
    FormatLabel->setEnabled(true);
    Format->setEnabled(true);
    Format->setText("%id");
    QToolTip::add( Format, tr2i18n( "%id<br>%title<br>%time<br>%remain<br>%length<br>%full" ) );
    LineLabel->setEnabled(false);
    Line->setEnabled(false);
    RDF->setEnabled(false);
  }
  else if(SensorCombo->currentItem() == 9){
    ProgramLabel->setEnabled(false);
    Program->setEnabled(false);
    CodecLabel->setEnabled(true);
    Codec->setEnabled(true);
    Codec->setText((QTextCodec::codecForLocale())->name());
    FormatLabel->setEnabled(true);
    Format->setEnabled(true);
    Format->setText("%title");
    QToolTip::add( Format, tr2i18n( "<b>Outputs</b><br>%title<br>%time<br>%remain<br>%length<br>%full<br>%stitle<br>%artist<br>%album<br>%track<br>%cover<br>%rcover<br>%viewer<br>%rate<br>%freq<br>%channel<br>%monoster<br>%runquit<br>%vol<br>%ms<br><b>Actions</b><br>%volup<br>%voldown<br>%prev<br>%play<br>%pause<br>%stop<br>%next<br>%list<br>%pref<br>%onoff" ) );
    LineLabel->setEnabled(false);
    Line->setEnabled(false);
    RDF->setEnabled(false);
  }
  else if(SensorCombo->currentItem() == 10){
    ProgramLabel->setEnabled(true);
    ProgramLabel->setText( tr2i18n( "Program:" ) );
    Program->setEnabled(true);
    CodecLabel->setEnabled(true);
    Codec->setEnabled(true);
    Codec->setText((QTextCodec::codecForLocale())->name());
    FormatLabel->setEnabled(true);
    Format->setEnabled(true);
    Format->setText("%v");
    QToolTip::add( Format, tr2i18n( "%v" ) );
    LineLabel->setEnabled(true);
    LineLabel->setText( tr2i18n( "Line:" ) );
    Line->setEnabled(true);
    Line->setText("");
    RDF->setEnabled(false);
  }
}

void ChildDlg::selTheme(){
    KSimpleConfig conf("karambarc",true);
    conf.setGroup("karamba");
    QString Dir = conf.readEntry("ThemeDir", locateLocal("data", "karamba/themes/"));
    QString theme;
    theme = KFileDialog::getOpenFileName(Dir, "*.theme", 0, "Open theme");
    if( theme != ""){
      Theme->setText( theme );
    }
}

#include "childdlg.moc"
