#include "ntheme.h"

/*
 *  Constructs a NTheme as a child of 'parent', with the 
 *  name 'name' and widget flags set to 'f'.
 *
 *  The dialog will by default be modeless, unless you set 'modal' to
 *  TRUE to construct a modal dialog.
 */
NTheme::NTheme( QWidget* parent, const char* name, bool modal, WFlags fl ) : QDialog( parent, name, modal, fl ){
    if ( !name )
	setName( "NTheme" );
    setMinimumSize( QSize( 600, 410 ) );
    setMaximumSize( QSize( 600, 410 ) );

    groupBox1 = new QGroupBox( this, "groupBox1" );
    groupBox1->setGeometry( QRect( 20, 0, 560, 110 ) );
    groupBox1->setFrameShape( QGroupBox::GroupBoxPanel );
    groupBox1->setFrameShadow( QGroupBox::Sunken );

    groupBox2 = new QGroupBox( this, "groupBox2" );
    groupBox2->setGeometry( QRect( 20, 120, 560, 220 ) );

    textLabel1 = new QLabel( groupBox1, "textLabel1" );
    textLabel1->setGeometry( QRect( 80, 30, 60, 21 ) );
    textLabel1->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignRight ) );

    textLabel2 = new QLabel( groupBox1, "textLabel2" );
    textLabel2->setGeometry( QRect( 80, 70, 60, 21 ) );
    textLabel2->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignRight ) );

    textLabel3 = new QLabel( groupBox1, "textLabel3" );
    textLabel3->setGeometry( QRect( 320, 30, 60, 21 ) );
    textLabel3->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignRight ) );

    textLabel4 = new QLabel( groupBox1, "textLabel4" );
    textLabel4->setGeometry( QRect( 320, 70, 60, 21 ) );
    textLabel4->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignRight ) );

    spinBox1 = new QSpinBox( groupBox1, "spinBox1" );
    spinBox1->setGeometry( QRect( 150, 30, 70, 21 ) );
    spinBox1->setMaxValue( 2048 );

    spinBox2 = new QSpinBox( groupBox1, "spinBox2" );
    spinBox2->setGeometry( QRect( 150, 70, 70, 21 ) );
    spinBox2->setMaxValue( 1200 );

    spinBox3 = new QSpinBox( groupBox1, "spinBox3" );
    spinBox3->setGeometry( QRect( 390, 30, 70, 21 ) );
    spinBox3->setMaxValue( 2048 );
    spinBox3->setValue( 300 );

    spinBox4 = new QSpinBox( groupBox1, "spinBox4" );
    spinBox4->setGeometry( QRect( 390, 70, 70, 21 ) );
    spinBox4->setMaxValue( 1200 );
    spinBox4->setValue( 300 );

    textLabel5 = new QLabel( groupBox2, "textLabel5" );
    textLabel5->setGeometry( QRect( 60, 30, 90, 21 ) );
    textLabel5->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignRight ) );

    spinBox5 = new QSpinBox( groupBox2, "spinBox5" );
    spinBox5->setGeometry( QRect( 160, 30, 80, 21 ) );
    spinBox5->setMaxValue( 100000 );
    spinBox5->setValue( 5000 );

    Fading = new QCheckBox( groupBox2, "Fading" );
    Fading->setGeometry( QRect( 320, 30, 160, 21 ) );

    textLabel6 = new QLabel( groupBox2, "textLabel6" );
    textLabel6->setGeometry( QRect( 2, 60, 148, 21 ) );
    textLabel6->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignRight ) );

    hideCombo = new QComboBox( groupBox2, "hideCombo" );
    hideCombo->setGeometry( QRect( 160, 60, 100, 21 ) );

    textLabel7 = new QLabel( groupBox2, "textLabel7" );
    textLabel7->setGeometry( QRect( 300, 60, 80, 21 ) );
    textLabel7->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignRight ) );

    spinBox6 = new QSpinBox( groupBox2, "spinBox6" );
    spinBox6->setGeometry( QRect( 390, 60, 80, 21 ) );
    spinBox6->setMaxValue( 100000 );
    spinBox6->setMinValue( 1 );
    spinBox6->setValue( 20 );

    checkGroup = new QButtonGroup ( groupBox2, "checkGroup" );
    checkGroup->setExclusive ( true );
    checkGroup->setGeometry( QRect( 40, 115, 480, 90 ) );

    checkBox1 = new QCheckBox( checkGroup, "checkBox1" );
    checkBox1->setGeometry( QRect( 20, 5, 160, 21 ) );

    checkBox4 = new QCheckBox( checkGroup, "checkBox4" );
    checkBox4->setGeometry( QRect( 280, 5, 160, 21 ) );

    checkBox2 = new QCheckBox( checkGroup, "checkBox2" );
    checkBox2->setGeometry( QRect( 20, 35, 160, 21 ) );

    checkBox5 = new QCheckBox( checkGroup, "checkBox5" );
    checkBox5->setGeometry( QRect( 280, 35, 160, 21 ) );

    checkBox7 = new QCheckBox( checkGroup, "checkBox7" );
    checkBox7->setGeometry( QRect( 20, 65, 160, 21 ) );

    checkBox3 = new QCheckBox( groupBox2, "checkBox3" );
    checkBox3->setGeometry( QRect( 60, 90, 160, 21 ) );

    checkBox6 = new QCheckBox( groupBox2, "checkBox6" );
    checkBox6->setGeometry( QRect( 320, 90, 160, 21 ) );

    noHead = new QCheckBox( this, "noHead" );
    noHead->setGeometry( QRect( 20, 345, 160, 21 ) );

    pushButton1 = new QPushButton( this, "pushButton1" );
    pushButton1->setGeometry( QRect( 190, 370, 81, 31 ) );
    pushButton1->setIconSet( SmallIconSet( "ok" ));
    pushButton1->setDefault(true);

    pushButton2 = new QPushButton( this, "pushButton2" );
    pushButton2->setGeometry( QRect( 340, 370, 81, 31 ) );
    pushButton2->setIconSet( SmallIconSet( "cancel" ));

    languageChange();

    // signals and slots connections
    connect( pushButton1, SIGNAL( clicked() ), this, SLOT( createTheme() ) );
    connect( pushButton2, SIGNAL( clicked() ), this, SLOT( close() ) );
    connect( spinBox1, SIGNAL( valueChanged( int ) ), this, SLOT( XunCheck() ) );
    connect( spinBox2, SIGNAL( valueChanged( int ) ), this, SLOT( YunCheck() ) );
    connect( noHead, SIGNAL( toggled( bool ) ), groupBox1, SLOT( setDisabled( bool ) ) );
    connect( noHead, SIGNAL( toggled( bool ) ), groupBox2, SLOT( setDisabled( bool ) ) );
}

/*
 *  Destroys the object and frees any allocated resources
 */
NTheme::~NTheme(){
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void NTheme::languageChange(){
    setCaption( tr2i18n( "New Karamba Theme" ) );
    groupBox1->setTitle( tr2i18n( "Size And Position" ) );
    groupBox2->setTitle( tr2i18n( "Others" ) );
    spinBox1->setPrefix( QString::null );
    spinBox1->setSuffix( tr2i18n( "px" ) );
    textLabel1->setText( tr2i18n( "X axis:" ) );
    textLabel2->setText( tr2i18n( "Y axis:" ) );
    textLabel3->setText( tr2i18n( "Width:" ) );
    textLabel4->setText( tr2i18n( "Height:" ) );
    textLabel5->setText( tr2i18n( "Interval:" ) );
    textLabel6->setText( tr2i18n( "Auto Hiding:" ) );
    textLabel7->setText( tr2i18n( "Limit:" ) );
    spinBox2->setPrefix( QString::null );
    spinBox2->setSuffix( tr2i18n( "px" ) );
    spinBox3->setPrefix( QString::null );
    spinBox3->setSuffix( tr2i18n( "px" ) );
    spinBox4->setPrefix( QString::null );
    spinBox4->setSuffix( tr2i18n( "px" ) );
    spinBox5->setPrefix( QString::null );
    spinBox5->setSuffix( tr2i18n( "ms" ) );
    spinBox6->setPrefix( QString::null );
    spinBox6->setSuffix( tr2i18n( "px" ) );
    Fading->setText( tr2i18n( "FADE parameter" ) );
    QToolTip::add( Fading, tr2i18n( "If FADE=true the Karamba window background will be fade with color selected with configuration dialog.<br>Default: FADE=false" ) );
    checkBox1->setText( tr2i18n( "RIGHT parameter" ) );
    QToolTip::add( checkBox1, tr2i18n( "If RIGHT=true the Karamba window will be placed at the right side of the screen.<br>The X parameter is ignored.<br>Default: RIGHT=false" ) );
    checkBox2->setText( tr2i18n( "BOTTOM parameter" ) );
    QToolTip::add( checkBox2, tr2i18n( "If BOTTOM=true the Karamba window will be placed at the bottom of the screen.<br>The Y parameter is ignored." ) );
    checkBox3->setText( tr2i18n( "ONTOP parameter" ) );
    QToolTip::add( checkBox3, tr2i18n( "ONTOP=true will put the Karamba window ontop of others windows.<br>Default: ONTOP=false." ) );
    checkBox4->setText( tr2i18n( "TOPBAR parameter" ) );
    QToolTip::add( checkBox4, tr2i18n( "TOPBAR=true puts the window at the top of the screen, and maximized applications will not cover the Karamba window(This works like Kicker, the KDE desktop panel.).<br>The Karamba window can not be moved if TOPBAR=true.<br>Default: TOPBAR=false" ) );
    checkBox5->setText( tr2i18n( "BOTTOMBAR parameter" ) );
    QToolTip::add( checkBox5, tr2i18n( "BOTTOMBAR=true puts the window at the bottom of the screen, and maximized applications will not cover the Karamba window.<br>(This works like Kicker, the KDE desktop panel.)<br>The Karamba window can not be moved if BOTTOMBAR=true.<br>Default: BOTTOMBAR=false" ) );
    checkBox6->setText( tr2i18n( "LOCKED parameter" ) );
    QToolTip::add( checkBox6, tr2i18n( "A LOCKED=true Karamba window can not be moved by click-n-drag.<br>This can also be changed by right-clicking on the window.<br>Default: LOCKED=false" ) );
    checkBox7->setText( tr2i18n( "CENTER parameter" ) );
    QToolTip::add( checkBox7, tr2i18n( "If CENTER=true the Karamba window will be centered in the screen.<br>The X and Y parameters are ignored." ) );
    hideCombo->clear();
    hideCombo->insertItem( tr2i18n( "none" ) );
    hideCombo->insertItem( tr2i18n( "Left" ) );
    hideCombo->insertItem( tr2i18n( "Right" ) );
    hideCombo->insertItem( tr2i18n( "Top" ) );
    hideCombo->insertItem( tr2i18n( "Bottom" ) );
    noHead->setText( tr2i18n("No KARAMBA header (check only if you want to create a multi-themes launcher).") );
    noHead->adjustSize();
    pushButton2->setText( tr2i18n( "Cancel" ) );
    pushButton1->setText( tr2i18n( "Ok" ) );
}

void NTheme::createTheme(){
    accept();
}

void NTheme::XunCheck(){
    if(checkBox1->isOn()){
      checkBox1->toggle();
    }
    if(checkBox7->isOn()){
      checkBox7->toggle();
    }
}

void NTheme::YunCheck(){
    if(checkBox2->isOn()){
      checkBox2->toggle();
    }
    if(checkBox4->isOn()){
      checkBox4->toggle();
    }
    if(checkBox5->isOn()){
      checkBox5->toggle();
    }
    if(checkBox7->isOn()){
      checkBox7->toggle();
    }
}

#include "ntheme.moc"
