/*
 * Copyright (C) 2003 Hans Karlsson <karlsson.h@home.se>
 */


#include <kapplication.h>
#include <kfiledialog.h>
#include <kaboutdata.h>
#include <kcmdlineargs.h>
#include <klocale.h>
#include <kconfig.h>
#include <ksimpleconfig.h>
#include <kstandarddirs.h>

#include <qurl.h>
#include <qfileinfo.h>
#include <qstringlist.h>

#include "karamba.h"
#include "karambaconf.h"


static const char *description = I18N_NOOP("A KDE Eye-candy Application");

static const char *version = "0.23";

static KCmdLineOptions options[] ={{ "s", 0, 0 },{ "setup", I18N_NOOP("Configure KarambaR."), 0 },{ "+file", I18N_NOOP("Theme to open."), 0 },{ 0, 0, 0 }};

int main(int argc, char **argv){
    KAboutData about("karamba", I18N_NOOP("karamba"), version, description,
    KAboutData::License_GPL, "(C) 2003 Hans Karlsson", 0, 0, "karlsson.h@home.se");
    about.addAuthor( "Hans Karlsson", 0, "karlsson.h@home.se" );
    about.addAuthor( "Bosselut Cyril",I18N_NOOP("Karamba Replica") , "bosselut@b1project.com" );
    about.setTranslator(I18N_NOOP("INSERT YOUR NAME HERE"),I18N_NOOP("INSERT YOUR EMAIL ADDRESS"));
    KCmdLineArgs::init(argc, argv, &about);
    KCmdLineArgs::addCmdLineOptions( options );

    KApplication app;
    karamba *mainWin = 0;

    KCmdLineArgs *args = KCmdLineArgs::parsedArgs();

    KSimpleConfig conf("karambarc",true);
    conf.setGroup("karamba");
    QString dDir =  conf.readEntry("ThemeDir", locateLocal("data", "karamba/themes/"));
    QString dTheme =  conf.readEntry("DefaultTheme", "");
    if(args->isSet("setup")){
      KarambaConf *kc = 0;
      kc = new KarambaConf(0, "karconf", false, 0);
      kc->exec();
    }
    else{
      bool OK = false;
      if(args->count() > 0){
          for (int i = 0; i < (args->count()); i++){
              if( args->arg(i) != "" ){
                  QFileInfo file( args->arg(i) );
                  if( file.exists() && !file.isDir() ){
                      mainWin = new karamba( 0, ( args->arg(i) ) );
                      OK = true;
                  }
              }
          }

          int ret = 0;
          if( OK )
              ret = app.exec();
          return ret;
      }
      else if(dTheme != ""){
        QUrl url(dTheme); //make QUrl from QString
        QString dir = url.dirPath (); //resolve the absolute path
        QString fn = (dir == ".")?dDir + "/" + dTheme:dTheme; //verify if the theme is in default dir
        QFileInfo file( fn );
        if( file.exists() && !file.isDir() ){ //verify if theme exist
          mainWin = new karamba( 0, fn );
          OK = true;
        }
        int ret = 0;
        if( OK ){
            ret = app.exec();
        }
        return ret;
      }
      else{
          QStringList fileNames;
          fileNames = KFileDialog::getOpenFileNames(dDir, "*.theme", 0, "Open configurations");
          for ( QStringList::Iterator it = fileNames.begin(); it != fileNames.end(); ++it ){
              QFileInfo file( *it );
              if( file.exists() && !file.isDir() ){
                  mainWin = new karamba( 0, *it );
                  OK = true;
              }
          }
          int ret = 0;
          if( OK ){
              ret = app.exec();
          }
          return ret;
      }
    }
    args->clear();
    return 0;

}
