/***************************************************************************
 *   Copyright (C) 2003 by Hans Karlsson                                   *
 *   karlsson.h@home.se                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 ***************************************************************************/
#include "textlabel.h"

TextLabel::TextLabel( int x,int y,int w,int h)
        : Meter(x,y,w,h)
{
    position = 0;
    len = 0;
    move = 0;
    lineHeight = QFontMetrics(font).height();
    if( h != 0){
        clip = 0;
    }
    else{
        clip = Qt::DontClip;
    }
    height = (h == 0)?-1:h;
    width = (w == 0)?-1:w;
}

TextLabel::TextLabel()
{
}

TextLabel::~TextLabel()
{
}

void TextLabel::setKaramba(karamba* k)
{
	myKaramba = k;
}

void TextLabel::setValue( QString text)
{
    text = (text == 0)?"Karamba Enhance Your Desktop":text;
    value = QStringList::split('\n',text);
}

void TextLabel::setValue( int v)
{
    value = QStringList( QString::number( v ) );
}

void TextLabel::setColor(int r, int g, int b)
{
    color.setRgb(r,g,b);
}

QColor TextLabel::getColor() const
{
    return color;
}

void TextLabel::setMove ( int m )
{
    move = m;
}

int TextLabel::getMove() const
{
    return move;
}

void TextLabel::setMaxMove ( int mx )
{
    mm = mx;
}

int TextLabel::getMaxMove() const
{
    return mm;
}

void TextLabel::setBGColor( int r, int g, int b )
{
    bgColor.setRgb( r, g, b );
}

QColor TextLabel::getBGColor() const
{
    return bgColor;
}


void TextLabel::setFont(QString f)
{
    font.setFamily(f);
    lineHeight = QFontMetrics(font).height();
}


QString TextLabel::getFont() const
{
    return font.family();
}

void TextLabel::setFontSize(int size)
{
    font.setPointSize(size);
    lineHeight = QFontMetrics(font).height();
}

int TextLabel::getFontSize() const
{
    return font.pointSize();
}

void TextLabel::setAlignment( QString align )
{
    QString a = align.upper();
    if( a == "LEFT" || a == "" )
        alignment = Qt::AlignLeft;
    if( a == "RIGHT" )
        alignment = Qt::AlignRight;
    if( a == "CENTER" )
        alignment = Qt::AlignHCenter;
}

QString TextLabel::getAlignment() const
{
    if( alignment == Qt::AlignHCenter )
        return "CENTER";
    else if( alignment == Qt::AlignRight )
        return "RIGHT";
    else
        return "LEFT";
}

void TextLabel::setFixedPitch( bool fp)
{
    font.setFixedPitch( fp );
}

bool TextLabel::getFixedPitch() const
{
    return font.fixedPitch();
}

void TextLabel::setShadow ( int s )
{
    shadow = s;
}


int TextLabel::getShadow() const
{
    return shadow;
}


void TextLabel::mUpdate(QPainter *p){
  if( ( (myKaramba->x() + myKaramba->themeW) >= 0) && ( (myKaramba->x() + x) <= QApplication::desktop()->width()) && ( (myKaramba->y() + myKaramba->themeH) >= 0) && ( (myKaramba->y() + y) <= QApplication::desktop()->height()) ){
    int i = 0; //lineHeight;
    int row = 1;
    int nx;
    QFontMetrics fm( font );
    p->setFont(font);
    QStringList::Iterator it = value.begin();
    if(str != value.join("")){ //reinit values if text change
      str = value.join("");
      strsize = fm.width(str, -1);
      strlen = str.length();
      maxmove= getMaxMove();
    }
    if(move != 0){
      if(maxmove == 0){ //init maxvalues if maxmove == 0
        if(  width != -1 ){
          maxmove = width; //text in a box
        }
        else{
          maxmove = myKaramba->themeW; //text scroll all along the theme
        }
        position = 0;
      }
      if(move > 0){ // move from left to right
        if(position >= maxmove){
          position = 0 - strsize;
        }
        else{
         position += move;
       }
     }
     else{ // move from right to left
        if(position + strsize == 0){
          if(  width != -1 ){
            position = width;
          }
          else{
            position = maxmove;
          }
        }
        else{
         position += move;
       }
     }
     nx = position + x;
     if(  width != -1 ){
        if(nx >= width){ //text out of zone: don't show
          len = 0;
        }
        else{
          if((width - nx) > fm.width(str, len) && len >= 0){ //a part of text feet in zone (move left to right)
              len++;
          }
          if((width - nx) < fm.width(str, len) && move > 0){ //a part of text feet in zone (move right to left)
              len--;
          }
          else if( (width - nx) >= fm.width(str, strlen) ){ //full text feet in zone
            if(move < 0){
              len = -1;
            }
            else{
              len = strlen;
            }
          }
        }
      }
      else{
        len = -1;
      }
   }
    else{
      nx = x;
      position = 0;
      len = -1;
    }
    while( it != value.end() && (row <= height || height == -1 ) ){
       if( shadow != 0){
            p->setPen( bgColor );
            p->drawText(nx+shadow, y+i+shadow, width, height, alignment | clip | Qt::ExpandTabs,*it, len);
        }
        p->setPen( color );
        p->drawText(nx,y+i, width, height, alignment | clip | Qt::ExpandTabs,*it, len);
        i += lineHeight;
        it++;
        row++;
    }
  }
}






