/***************************************************************************
 *   Copyright (C) 2003 by Hans Karlsson                                   *
 *   karlsson.h@home.se                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 ***************************************************************************/
#ifndef XMMSSENSOR_H
#define XMMSSENSOR_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#ifdef HAVE_XMMS
#include <xmmsctrl.h>
#endif // HAVE_XMMS

#include <stdlib.h>
#include <stdio.h>
#include <qdatetime.h>
#include <qtextcodec.h>
#include <qtooltip.h>

#include <ksimpleconfig.h>
#include <kstandarddirs.h>

#include "sensor.h"
#include "clickarea.h"
#include "tags.h"

/**
 * @author Hans Karlsson <karlsson.h@home.se>
 * @author Bosselut Cyril <bosselut@b1project.com>
 * @version 0.23
 */

class XMMSSensor :  public Sensor
{
    Q_OBJECT
public:
    /**
    * create a new XMMS sensor with refresh interval "interval" and character encoding "encoding"
    */
    XMMSSensor( int interval, QString encoding="", int nw = 0, int nh = 0, karamba* k = 0 );
    /**
    * destructor
    */
    ~XMMSSensor();
    /**
    * update sensor display
    */
    void update();
    /**
    * cover thumbnail width
    */
    int w;
    /**
    * cover thumbnail height
    */
    int h;
    /**
    * default cover thumbnail width
    */
    int defW;
    /**
    * default cover thumbnail height
    */
    int defH;
    /**
    * volume
    */
    int vol;
    /**
    * music file path
    */
    QString dir;
     /**
    * cover thumbnail path
    */
   QString cover;
    /**
    * real cover path
    */
    QString rcover;
    /**
    * file pointer on temporary cover file
    */
    QString fp;
    /**
    * artist + title + album or xmms output title
    */
    QString title;
    /**
    * artist
    */
    QString artist;
    /**
    * album
    */
    QString album;
    /**
    * song title
    */
    QString stitle;
    /**
    * track number
    */
    QString track;
    /**
    * last position in playlist
    */
    int current;
    /**
    * music file
    */
    QString file;
    /**
    * bitrate in bps
    */
    int rate;
    /**
    * frequency in hz
    */
    double freq;
    /**
    * number of channel (1 = mono, 2 = stereo)
    */
    int channel;
    /**
    * QString "mono" or "stereo"
    */
    QString monoster;
    /**
    * position in playlist
    */
    int pos;
    /**
    * song length
    */
    int songLength;
    /**
    * Time elapsed
    */
    int currentTime;

private:
    /**
    * set sensor max values
    */
    void setMaxValue( SensorParams *);
    /**
    * get cover width from karambarc
    */
    int getW( int nw = 0 );
    /**
    * get cover height from karambarc
    */
    int getH(int nh = 0 );
    /**
    * pass Karamba pointer to sensor
    */
    void setKaramba(karamba*);
    /**
    * text encoding
    */
    QTextCodec *codec;
    /**
    * pointer on Karamba instance
    */
    karamba* myKaramba;
    /**
    * Hide/Show XMMS main window
    */
    bool HideMainWin;
    /**
    * Enabled search and display cover
    */
    bool EnableCover;
    /**
    * Cover viewer
    */
    QString Viewer;
    bool EnableID3;
    bool SaveID3;
    bool EnableID3C;
    bool NetCover;

private slots:
    void slotUpValues();
    void slotGetCover( Tags* );
    void slotGetPos();

public slots:
    /**
    * Use this slot to read karambarc.
    */
    void slotLoadConfig(  );

signals:
    void songChange();

};


#endif // XMMSSENSOR_H
